---
title: <span class="badge object-type-scalar"></span> Lux
---
# <span class="badge object-type-scalar"></span> Lux

Flow: Lux (lx)

## Definition

```python
# Flow: Lux (lx)
Lux: typing.Literal["lux"] = "lux"
```
